@@ -40,11 +40,7 @@ pub fn count_inv_tens(mut num: f64) -> u128 {
 }
 
 pub fn divs(lhs: &[f64], rhs: f64) -> Vec<f64> {
-    let mut out = Vec::with_capacity(lhs.len());
-    for val in lhs.iter() {
-        out.push(val / rhs);
-    }
-    out
+    lhs.iter().map(|v| v / rhs).collect()
 }
 
 pub fn sub(lhs: &[f64], rhs: f64) -> Vec<f64> {
@@ -92,23 +88,38 @@ pub fn get_steps(max: f64, mut min_steps: f64) -> f64 {
     min_steps
 }
 
-pub fn max_display(max: f64) -> f64 {
+pub fn max_display(max: f64, other_scaling: bool) -> f64 {
     if max == 0. {
         return 1.;
     }
     if max >= 2. { 
-        let tens = count_tens(max);
-        ((max / tens as f64 / 2.).round() * tens as f64) * 2.
-        /*
-        let tens = count_tens(max) / 10;
+        
+        /*let tens = count_tens(max) / 10;
         if tens == 0 {
             return max;
         }
         if tens == 1 {
             return (max / 10.).round() * 10.;
         }
-        ((max / tens as f64 / 2.).round() * tens as f64) * 2.
-        */
+
+        ((max / tens as f64 / 2.).round() * tens as f64) * 2.*/
+            
+        if other_scaling {
+            let tens = count_tens(max) / 10;
+            if tens == 0 {
+                return max;
+            }
+            if tens == 1 {
+                return (max / 10.).round() * 10.;
+            }
+            ((max / tens as f64 / 2.).round() * tens as f64) * 2.
+        } else {
+            let tens = count_tens(max);
+            ((max / tens as f64 / 2.).round() * tens as f64) * 2.
+        }
+        
+        
+
         /*
         let new_max = (max / 10f64).round() * 10.;
         if new_max == 0. {
